# asciiglet.

asciiglet is an ASCII-based graphics library.

### Tech

* [pyglet][pyglet]

### Installation

Asciiglet is published and distributed via PyPI.

```sh
pip install asciiglet
```

Or installed directly from [public repository][asciiglet].

### Plugins

Asciiglet doesn't have plugins as it's too no-name of a package to begin with. Probably never going to even receive an update, so it can't introduce any API compatibility issues never-ever-ever!

### To-dos

 - Write tests.
 - Make usable.
 - Make better.

### Discussion

Any non-technical discussion(which probably should take place on [github][asciiglet]), please proceed to this library's [Discord][asciigletdiscord]!

License
----

MIT


**Free Software, Oh Yeah!**

[//]: #
   [asciiglet]: <https://github.com/LudwigVonChesterfield/asciiglet>
   [git-repo-url]: <https://github.com/LudwigVonChesterfield/asciiglet.git>
   [pyglet]: <https://pypi.org/project/pyglet/>
   [asciigletdiscord]: <https://discord.gg/ZW6ebCQbX7>
